@@ -3,6 +3,7 @@ from dataclasses import dataclass, field
 from typing import TYPE_CHECKING
 
 from .contacts import Contacts
+from .tasks import Tasks
 from .timelines import Timelines
 
 if TYPE_CHECKING:
@@ -15,9 +16,11 @@ class RTM:
 
     api: "Auth"
     contacts: "Contacts" = field(init=False)
+    tasks: "Tasks" = field(init=False)
     timelines: "Timelines" = field(init=False)
 
     def __post_init__(self) -> None:
         """Set up the instance."""
         self.contacts = Contacts(self.api)
+        self.tasks = Tasks(self.api)
         self.timelines = Timelines(self.api)
